"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = start;

require("universal-dotenv");

var _path = _interopRequireDefault(require("path"));

var _fs = require("fs");

var _os = require("os");

var _listr = _interopRequireDefault(require("listr"));

var _clearConsole = _interopRequireDefault(require("react-dev-utils/clearConsole"));

var _execa = _interopRequireDefault(require("execa"));

var _ngrok = require("ngrok");

var _babelPluginUniversalDotenv = require("babel-plugin-universal-dotenv");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// eslint-disable-line import/no-extraneous-dependencies
async function start({
  web = true,
  node = true,
  mongod,
  redis,
  ngrok: ngrokArg
} = {}) {
  const env = { ...(0, _babelPluginUniversalDotenv.expand)(process.env.NODE_ENV),
    ...process.env
  };

  if (process.env.NODE_ENV === 'production') {
    return (0, _execa.default)('forever', [(0, _fs.existsSync)('./lib/index.node.js') ? 'lib/index.node.js' : 'lib/index.js'], {
      env: { ...env,
        NODE_ENV: 'production'
      },
      stdio: 'inherit'
    });
  }

  const {
    PORT = 3000,
    NODE_PORT = 4000,
    MONGOD_PORT = 27017,
    REDIS_PORT = 6379,
    BROWSER: PREVIOUS_BROWSER
  } = env;
  await new _listr.default([{
    title: 'Downloading mongod',
    enabled: () => mongod && !(0, _fs.existsSync)(_path.default.resolve((0, _os.homedir)(), '.mongodb-prebuilt')),
    task: () => (0, _execa.default)('mongod', ['--version']).stdout
  }, {
    title: 'Downloading redis',
    enabled: () => redis && !(0, _fs.existsSync)(_path.default.resolve((0, _os.homedir)(), '.redis-prebuilt')),
    task: () => (0, _execa.default)('redis-server', ['--version']).stdout
  }], {
    renderer: process.env.NODE_ENV === 'test' ? 'silent' :
    /* istanbul ignore next */
    'default',
    exitOnError: false,
    concurrent: true
  }).run();

  if (process.stdout.isTTY) {
    (0, _clearConsole.default)();
  }

  const ngrok = ngrokArg && web;
  /*
   * https://github.com/strongloop/node-foreman/blob/master/lib/colors.js#L7
   * The order dictates the color
   */

  const formation = Object.entries({
    node,
    // magenta
    foo2: false,
    // blue
    web,
    // cyan
    mongod,
    // green
    foo5: false,
    // yellow
    redis // red

  });
  const formationTrimmed = formation.slice(0, formation.map(([, val]) => val).lastIndexOf(true) + 1);
  const ports = {
    web: PORT,
    node: NODE_PORT,
    mongod: MONGOD_PORT,
    redis: REDIS_PORT
  };
  return (0, _execa.default)('nf', ['start', '--procfile', _path.default.resolve(__dirname, 'Procfile'), '-x', formationTrimmed.map(([key]) => ports[key] || 0).join(','), formationTrimmed.map(([key, val], index) => val ? `${key}=1` : `foo${index + 1}=0`).join(',')], {
    env: { ...env,
      NODE_ENV: 'development',
      BROWSER: _path.default.resolve(__dirname, 'open-url.js'),
      PREVIOUS_BROWSER,
      HTTPS: false,
      ...(web && {
        URL_TO_OPEN: `http://localhost:${PORT}`,
        SKIP_PREFLIGHT_CHECK: true
      }),
      ...(node && {
        src: (0, _fs.existsSync)('./src/index.node.js') ? 'src/index.node' : 'src',
        root: __dirname
      }),
      ...(mongod && {
        MONGODB_URI: `mongodb://localhost:${MONGOD_PORT}/database`,
        MONGOHQ_URL: `mongodb://localhost:${MONGOD_PORT}/database`,
        ORMONGO_URL: `mongodb://localhost:${MONGOD_PORT}/database`
      }),
      ...(redis && {
        OPENREDIS_URL: `redis://localhost:${REDIS_PORT}`,
        REDISCLOUD_URL: `redis://localhost:${REDIS_PORT}`,
        REDISGREEN_URL: `redis://localhost:${REDIS_PORT}`,
        REDISTOGO_URL: `redis://localhost:${REDIS_PORT}`,
        REDIS_URL: `redis://localhost:${REDIS_PORT}`
      }),
      ...(ngrok && {
        URL_TO_OPEN: await (0, _ngrok.connect)({
          bind_tls: true,
          // eslint-disable-line camelcase
          host_header: 'localhost',
          // eslint-disable-line camelcase
          port: PORT
        })
      })
    },
    stdio: 'inherit'
  });
}
//# sourceMappingURL=react-node-scripts-start.js.map